@@ -4,6 +4,7 @@ from z3c.pt.expressions import ZopeExistsTraverser
 from z3c.pt.expressions import ProviderTranslator
 
 from zExceptions import NotFound, Unauthorized
+from OFS.interfaces import ITraversable
 
 from zope import component
 from zope.traversing.adapters import traversePathElement
@@ -22,11 +23,9 @@ except ImportError:
     AQ_WRAP_CP = False
     
 class FiveTraverser(object):
-    def __call__(self, base, request, call, *path_items):
+    def __call__(self, base, scope, call, *path_items):
         """See ``zope.app.pagetemplate.engine``."""
 
-        ob = base
-        
         length = len(path_items)
         if length:
             i = 0
@@ -41,9 +40,11 @@ class FiveTraverser(object):
                     # special-case dicts for performance reasons
                     if isinstance(base, dict):
                         base = base[name]
+                    elif ITraversable.providedBy(base):
+                        base = base.restrictedTraverse(name)
                     else:
                         base = traversePathElement(
-                            base, name, path_items[i:], request=request)
+                            base, name, path_items[i:], request=scope['request'])
 
         if call is False:
             return base
@@ -51,12 +52,13 @@ class FiveTraverser(object):
         if getattr(base, '__call__', _marker) is not _marker or callable(base):
             # here's where we're different from the standard path
             # traverser
-            base = render(base, ob)
+            base = render(base, scope)
 
         return base
 
 class PathTranslator(PathTranslator):
     path_traverse = FiveTraverser()
+    scope = 'locals()'
 
 class FiveExistsTraverser(ZopeExistsTraverser):
     exceptions = AttributeError, LookupError, TypeError, \
